<?php

namespace Drupal\flag_lists\Entity;

use Drupal\Core\Entity\ContentEntityInterface;
use Drupal\Core\Entity\EntityChangedInterface;
use Drupal\user\EntityOwnerInterface;

/**
 * Provides an interface for defining Flag list item entities.
 *
 * @ingroup flag_lists
 */
interface FlagListItemInterface extends ContentEntityInterface, EntityChangedInterface, EntityOwnerInterface {

  // Add get/set methods for your configuration properties here.

  /**
   * Gets the Flag list item name.
   *
   * @return string
   *   Name of the Flag list item.
   */
  public function getName();

  /**
   * Sets the Flag list item name.
   *
   * @param string $name
   *   The Flag list item name.
   *
   * @return \Drupal\flag_lists\Entity\FlagListItemInterface
   *   The called Flag list item entity.
   */
  public function setName($name);

  /**
   * Gets the Flag list item creation timestamp.
   *
   * @return int
   *   Creation timestamp of the Flag list item.
   */
  public function getCreatedTime();

  /**
   * Sets the Flag list item creation timestamp.
   *
   * @param int $timestamp
   *   The Flag list item creation timestamp.
   *
   * @return \Drupal\flag_lists\Entity\FlagListItemInterface
   *   The called Flag list item entity.
   */
  public function setCreatedTime($timestamp);

  /**
   * Returns the Flag list item published status indicator.
   *
   * Unpublished Flag list item are only visible to restricted users.
   *
   * @return bool
   *   TRUE if the Flag list item is published.
   */
  public function isPublished();

  /**
   * Sets the published status of a Flag list item.
   *
   * @param bool $published
   *   TRUE to set this Flag list item to published, FALSE to set it to unpublished.
   *
   * @return \Drupal\flag_lists\Entity\FlagListItemInterface
   *   The called Flag list item entity.
   */
  public function setPublished($published);

}
