<?php

namespace Drupal\flag_lists\EventSubscriber;

use Symfony\Component\EventDispatcher\EventSubscriberInterface;
use Symfony\Component\EventDispatcher\Event;
use Drupal\Core\Messenger\MessengerTrait;
use Drupal\flag\Event\FlagEvents;
use Drupal\flag\Event\FlaggingEvent;
use Drupal\flag\Event\UnflaggingEvent;
use Drupal\flag_lists\Entity\FlagListItem;

/**
 * Class FlagForListSubscriber.
 */
class FlagForListSubscriber implements EventSubscriberInterface {
  use MessengerTrait;

  /**
   * Constructs a new FlagForListSubscriber object.
   */
  public function __construct() {

  }

  /**
   * {@inheritdoc}
   */
  static function getSubscribedEvents() {
    $events[FlagEvents::ENTITY_FLAGGED][] = array('flag_lists_entity_flagged', 100);
    $events[FlagEvents::ENTITY_UNFLAGGED][] = array('flag_lists_entity_unflagged', 100);
    return $events;
  }

  /**
   * This method is called whenever the flag.entity_flagged event is
   * dispatched.
   *
   * @param GetResponseEvent $event
   */
  public function flag_lists_entity_flagged(Event $flag_event) {

    $FlagId = $flag_event->getFlagging()->getFlagId();

    foreach (\Drupal::service('flaglists')->getAllFlagForList() as $collection) {
      if ($collection->getBaseFlag() == $FlagId) {
        $this->messenger()->addMessage(t('Entity added to the %flaglist list.',
          array('%flaglist' => $FlagId)));
      }
    
    }

  }

  /**
   * This method is called whenever the flag.entity_unflagged event is
   * dispatched.
   *
   * @param GetResponseEvent $event
   */
  public function flag_lists_entity_unflagged(Event $flag_events) {
    foreach($flag_events->getFlaggings() as $flagging) {

      $FlagId = $flagging->getFlagId();

      foreach (\Drupal::service('flaglists')->getAllFlagForList() as $collection) {
        if ($collection->getBaseFlag() == $FlagId) {
          $this->messenger()->addMessage(t('Entity removed from the %flaglist list.',
            array('%flaglist' => $FlagId)));
        }
    
      }
    }
  }

}
